#
# spec file for package libical
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor glib%{nil}
%define sonum   3
%if "%{flavor}" == "glib"
%define name_ext -glib
%bcond_without glib
%else
%define name_ext %{nil}
%bcond_with glib
%endif
Name:           libical%{name_ext}
Version:        3.0.18
Release:        1.1
URL:            https://github.com/libical/libical
Source:         %{url}/releases/download/v%{version}/libical-%{version}.tar.gz
Source2:        baselibs.conf
Source3:        libical-rpmlintrc
Patch1:         0001-vcc.y-factor-out-hexdigit-conversion.patch
Patch2:         0002-vcc.y-fix-infinite-loop-with-lower-case-hex-digits.patch
Patch3:         0003-vcc.y-fix-infinite-loop-with-non-hex-digits.patch
Patch4:         0004-vobject.c-vCard-Unicode-reading-support.patch
Patch5:         0005-vcc.y-do-not-ignore-field-separator-in-QUOTED-PRINTA.patch
BuildRequires:  c++_compiler
BuildRequires:  cmake >= 3.5
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(icu-i18n)
%if %{without glib}
Summary:        An Implementation of Basic iCAL Protocols
License:        LGPL-2.1-only OR MPL-2.0
Group:          Development/Libraries/C and C++
%else
Summary:        GObject wrapper for libical library
License:        LGPL-2.1-only OR MPL-2.0
Group:          Development/Libraries/C and C++
%endif
%if %{with glib}
BuildRequires:  gtk-doc
BuildRequires:  vala
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(libical)
BuildRequires:  pkgconfig(libxml-2.0)
%endif
%if %{without glib}
%description -n libical
Libical is an implementation of the IETF's iCalendar
calendaring and scheduling protocols (RFC 2445, 2446, and 2447). It
parses iCal components and provides a C API for manipulating the
component properties, parameters, and subcomponents.
%else

%description -n libical-glib
This package provides a GObject wrapper for libical library with support
for GObject Introspection.
%endif

%package -n libical%{sonum}
Summary:        An Implementation of Basic iCAL Protocols
Group:          System/Libraries
Provides:       libical = %{version}
Obsoletes:      libical < %{version}

%description -n libical%{sonum}
Libical is an implementation of the IETF's iCalendar
calendaring and scheduling protocols (RFC 2445, 2446, and 2447). It
parses iCal components and provides a C API for manipulating the
component properties, parameters, and subcomponents.

%package -n libical-devel
Summary:        Development files for libical, an implementation of basic iCAL protocols
Group:          Development/Libraries/C and C++
Requires:       libical%{sonum} = %{version}
# Typelib should be required, but might create a build cycle
# Requires:      typelib-1_0-libical%%{sonum} = %%{version}

%description -n libical-devel
Libical is an implementation of the IETF's iCalendar
Calendaring and Scheduling protocols. (RFC 2445, 2446, and 2447). It
parses iCal components and provides a C API for manipulating the
component properties, parameters, and subcomponents.

%package -n libical-doc
Summary:        Example source code for programs to use libical
Group:          Documentation/Other
BuildArch:      noarch

%description -n libical-doc
Libical is an implementation of the IETF's iCalendar
calendaring and scheduling protocols (RFC 2445, 2446, and 2447). It
parses iCal components and provides a C API for manipulating the
component properties, parameters, and subcomponents.

%package -n libical-glib%{sonum}
Summary:        GObject wrapper for libical library
Group:          System/Libraries
Provides:       libical-glib = %{version}
Obsoletes:      libical-glib < %{version}

%description -n libical-glib%{sonum}
This package provides a GObject wrapper for libical library with support
for GObject Introspection.

%package -n libical-glib-devel
Summary:        Development files for building against libical-glib
Group:          Development/Libraries/C and C++
Requires:       libical-glib%{sonum} = %{version}
Requires:       typelib-1_0-ICal-3_0 = %{version}
Requires:       typelib-1_0-ICalGLib-3_0 = %{version}

%description -n libical-glib-devel
Development files for building against libical-glib%{sonum}

%package -n libical-glib-doc
Summary:        Documentation files for libical-glib%{sonum}
Group:          Documentation/Other
BuildArch:      noarch

%description -n libical-glib-doc
Documentation files for %{name}%{sonum}

%package -n typelib-1_0-ICal-3_0
Summary:        Introspection bindings for libical
Group:          Development/Libraries/C and C++

%description -n typelib-1_0-ICal-3_0
This package provides the gobject-introspection bindings for libical.

%package -n typelib-1_0-ICalGLib-3_0
Summary:        Introspection bindings for the libical glib bindings.
Group:          Development/Libraries/C and C++

%description -n typelib-1_0-ICalGLib-3_0
This package provides the gobject-introspection bindings for libical-glib.

%prep
%autosetup -p1 -n libical-%{version}

%build
%cmake \
  -DICAL_ALLOW_EMPTY_PROPERTIES=true \
%if %{with glib}
  -DICAL_GLIB=true \
  -DGOBJECT_INTROSPECTION=true \
  -DICAL_GLIB_VAPI=true \
%else
  -DICAL_GLIB=false \
%endif
  -DSHARED_ONLY=true
%cmake_build

%install
%cmake_install
rm examples/CMakeLists.txt
%if %{with glib}
rm -r %{buildroot}%{_includedir}/libical/
rm -r %{buildroot}%{_libdir}/cmake/LibIcal
rm %{buildroot}%{_libdir}/libical.so*
rm %{buildroot}%{_libdir}/libical_cxx.so*
rm %{buildroot}%{_libdir}/libicalss.so*
rm %{buildroot}%{_libdir}/libicalss_cxx.so*
rm %{buildroot}%{_libdir}/libicalvcal.so*
rm %{buildroot}%{_libdir}/pkgconfig/libical.pc
%endif

%if %{without glib}
%post -n %{name}%{sonum} -p /sbin/ldconfig
%postun -n %{name}%{sonum} -p /sbin/ldconfig
%else
%post -n %{name} -p /sbin/ldconfig
%postun -n %{name} -p /sbin/ldconfig
%endif

%if %{without glib}
%files -n %{name}%{sonum}
%license COPYING
%doc AUTHORS README.md ReleaseNotes.txt TEST THANKS TODO
%{_libdir}/libical.so.*
%{_libdir}/libical_cxx.so.*
%{_libdir}/libicalss.so.*
%{_libdir}/libicalss_cxx.so.*
%{_libdir}/libicalvcal.so.*

%files devel
%{_libdir}/libical.so
%{_libdir}/libical_cxx.so
%{_libdir}/libicalss.so
%{_libdir}/libicalss_cxx.so
%{_libdir}/libicalvcal.so
%{_libdir}/pkgconfig/libical.pc
%{_libdir}/cmake/LibIcal/
%{_includedir}/libical/

%files doc
%doc doc/*.txt
%doc examples/
%else

%files -n %{name}%{sonum}
%{_libdir}/libical-glib.so.*

%files devel
%{_libdir}/libical-glib.so
%{_libdir}/pkgconfig/libical-glib.pc
%dir %{_libexecdir}/libical
%{_libexecdir}/libical/ical-glib-src-generator
%{_includedir}/libical-glib/
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/libical-glib.vapi
# This should really be in libical-devel
%{_datadir}/gir-1.0/ICal-3.0.gir
%{_datadir}/gir-1.0/ICalGLib-3.0.gir

%files doc
%{_datadir}/gtk-doc/html/libical-glib

%files -n typelib-1_0-ICal-3_0
%{_libdir}/girepository-1.0/ICal-3.0.typelib

%files -n typelib-1_0-ICalGLib-3_0
%{_libdir}/girepository-1.0/ICalGLib-3.0.typelib
%endif

%changelog
* Mon Apr 22 2024 Dirk Müller <dmueller@suse.com>
- update to 3.0.18:
  * Requires CMake v3.5.0 or higher
  * Escape ^ (U+005E) character in parameter values according to
    RFC 6868
  * New CMake option LIBICAL_BUILD_EXAMPLES to disable building
    the examples
  * Should be able to use the project as a submodule
  * Built-in timezones updated to tzdata2024a
* Sat Nov 18 2023 Dirk Müller <dmueller@suse.com>
- update to 3.0.17:
  * Escape commas in x-property TEXT values
  * Built-in timezones updated to tzdata2023c
  * icalparser_ctrl setting defines how to handle invalid CONTROL
    characters during parsing
  * New publicly available functions:
    + get_zone_directory()
    + icalparser_get_ctrl
    + icalparser_set_ctrl
* Wed Oct 19 2022 Chris Coutinho <chrisbcoutinho@gmail.com>
- Update to 3.0.16
  * Fix regressions in 3.0.15 due to improperly tested fuzz fixes
  * Fix argument guards in icaltime_as_timet to match documentation and tests.
* Fri Oct  7 2022 Dirk Müller <dmueller@suse.com>
- update to 3.0.15:
  * Add missing property parameters into libical-glib
  * Fix CMake option USE_32BIT_TIME_T actually uses a 32-bit time_t value
  * Fix icaltime_as_timet, which returned incorrect results for years >= 2100,
    to work properly between years 1902 and 10k.
  * Fix x-property comma handling and escaping
  * Built-in timezones updated to tzdata2022d (now with a VTIMEZONE for each time zone alias)
  * Fix fuzzer issues
  * Handle unreachable-code compile warnings with clang
  * Ensure all vanew_foo() calls finish with (void*)0 (not 0)
* Sun Mar 20 2022 Dirk Müller <dmueller@suse.com>
- update to 3.0.14:
  * icalvalue: Reset non-UTC icaltimetype::zone on set
  * Fix icalcomponent_set_due not removing TZID when necessary
* Fri Jan 21 2022 Dirk Müller <dmueller@suse.com>
- update to 3.0.13:
  * icalcomponent_get_dtend() return icaltime_null_time(), unless called on
    VEVENT, VAVAILABILITY or VFREEBUSY
  * icalcomponent_get_duration() for VTODO calculate with DUE instead of DTEND
  * Replace CMake FindBDB with FindBerleyDB
  * Fix finding ICU and BerkeleyDB on Mac
* Sat Dec 11 2021 Dirk Müller <dmueller@suse.com>
- update to 3.0.12:
  * Fix a libicalval crash in cleanVObject
  * METHOD:DECLINECOUNTER must have DTEND or DURATION
  * Handle if DTEND and DURATION are both missing
  * Improved FindICU (copied from official CMake)
  * Buildsystem fixes (especially for the Ninja generator)
  * Built-in timezones updated to tzdata2021e
* Mon Dec  6 2021 Dirk Müller <dmueller@suse.com>
- update to 3.0.11:
  * Fix icalrecur_iterator_set_start() for hourly, minutely, and secondly
    recurrences
  * Fix build for Berkeley DB version greater than 5
  * Fix vcal for some architectures (like aarch64, ppc64le and s390x)
  * Fix memory leaks in vcal
  * Prevent crash when looking for tzid in initialize_rscale
  * Adjust libdir and includedir in generated pkgconfig files
  * Built-in timezones updated to tzdata2021c
* Tue Apr 20 2021 Paolo Stivanin <info@paolostivanin.com>
- update to 3.0.10:
  * Fix generating wrong recurrence rules
  * Fix a bug computing transitions in tzfiles
  * Fix reading TZif files to use TZ string in the footer as the last
    (non-terminating) transitions
  * Fix reading TZif files to use more RRULEs and/or RDATEs whevever possible
  * Built-in timezones updated to tzdata2021a
* Wed Apr  7 2021 Dirk Müller <dmueller@suse.com>
- filelist fix for the glib build
* Sun Jan 24 2021 Dirk Müller <dmueller@suse.com>
- update to 3.0.9:
  * Add support for empty parameters, e.g. CN=""
  * Accept VTIMEZONE with more than one X- property
  * Several fixes for recurrences containing BYWEEKNO
  * icalrecurrencetype_from_string() will reject any RRULE that contains a
    rule-part that occurs more than once
  * Improve thread safety
  * Fix compiled-in path for the built-in timezone data
  * Fix reading TZif files with empty v1 data (use v2+ whenever possible)
  * Add backwards compatibility for previous TZIDs
  * Built-in timezones updated to tzdata2020d
  * Fix build with newer libicu
  * Fix cross-compile support in libical-glib
- remove 0001-Fix-build-with-icu-68.1.patch libical-read-v2-v3-data.patch:
  upstream
* Fri Dec  4 2020 Michael Gorse <mgorse@suse.com>
- Add 0001-Fix-build-with-icu-68.1.patch: fix build with icu 68.1.
* Tue Nov 17 2020 Michael Gorse <mgorse@suse.com>
- Add libical-read-v2-v3-data.patch: correctly read slim timezone
  data (bsc#1178412).
* Sat Apr 11 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.0.8:
  * Fix for icalattach_new_from_data() and the 'free_fn' argument.
  * Fix if recurrencetype contains both COUNT and UNTIL (only
    output UNTIL in the RRULE).
- Replace gcc-c++ with generic c++_compiler BuildRequires.
- Use cmake_build macro, forcing single thread building is no
  longer needed. This breaks support for SLE12SP4, but that one is
  superseeded by SP5 anyway.
* Thu Dec 19 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.0.7
  * Fix memory leaks in attachment handling and elsewhere.
  * Fix a multithreading race condition.
* Wed Oct 30 2019 Adam Majer <adam.majer@suse.de>
- Fix multibuild building. For baselibs.conf and _multibuild to
  work correctly, we need to define all possible %%package in the
  spec file irrespective of the "flavor". Packages are not generated
  if they do not have a %%files section
* Wed Oct 30 2019 Yifan Jiang <yfjiang@suse.com>
- Add pkgconfig(libical) BuildRequires: pkg-config 0.29.2 is not
  able to generate libical-glib pkgconfig dependency without
  libical.pc.
* Wed Oct 16 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Fix glib-devel dependencies on the typelib files after they were
  renamed to match the correct names.
* Wed Oct 16 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Add libical-glib3 to baselibs.conf: dependency to evolution.
* Wed Oct  9 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.0.6
  * Handle both COUNT and UNTIL in RRULEs
  * Fix RRULE BYDAY with INTERVAL=2 conflict
  * Various fuzzification fixes
  * New publicly available function:
    icaltimezone_truncate_vtimezone()
  * Add option to disable building the test suite
  * Built-in timezones updated to tzdata2019c
* Fri Oct  4 2019 Jan Engelhardt <jengelh@inai.de>
- Use proper grammar in description.
* Tue Oct  1 2019 Michael Gorse <mgorse@suse.com>
- Build glib and gobject-introspection bindings separately in order
  to avoid build cycle.
- Move gobject-introspection bindings into their own packages.
- Move libical gir into libical-glib-devel.
* Thu Aug 29 2019 Luke Jones <luke@ljones.dev>
- Enable libical-glib, required by evolution-data-server 3.33+
- Add rpmlintrc to filter typelib warnings
* Sun Jun  2 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 3.0.5
  * New publicly available function:
    icalproperty_get_datetime_with_component().
  * Allow reset DATE/DATE-TIME VALUE parameter for all-day events
  * icalproperty_get_datetime_with_component() will use location
    as TZID fallback.
  * Built-in timezones updated to tzdata2019a.
* Fri Nov  9 2018 Jan Engelhardt <jengelh@inai.de>
- Add patches 0001-vcc.y-factor-out-hexdigit-conversion.patch,
  0002-vcc.y-fix-infinite-loop-with-lower-case-hex-digits.patch,
  0003-vcc.y-fix-infinite-loop-with-non-hex-digits.patch,
  0004-vobject.c-vCard-Unicode-reading-support.patch,
  0005-vcc.y-do-not-ignore-field-separator-in-QUOTED-PRINTA.patch
  to support Unicode in VCF (and fix infinite loops).
  [https://github.com/libical/libical/pull/354 ]
* Thu Aug 23 2018 jengelh@inai.de
- Update to new upstream release 3.0.4
  * Silently fail RSCALE recurrence clauses when RSCALE is disabled
  * Fixed icalcomponent_set_comment() and icalcomponent_set_uid()
  * fix FREQ=MONTHLY;BYMONTH
  * Skip UTF-8 marker when parsing
  * Fix parsing ? in VCF files produced by Outlook
  * Fix TZID on DATE-TIME value can override time specified in UTC
  * CMake discovery module for ICU uses pkg-config now
  * New publicly available function: icalparameter_kind_is_valid()
  * Built-in timezones updated to tzdata2018e
* Sat Mar  3 2018 jengelh@inai.de
- Update to new upstream release 3.0.3
  * Various changes to the API over 2.x.
  * Fixed use-after-free issues and some memory leaks
  * More accurate VTIMEZONE generation when using the system time
    zone data (when USE_BUILTIN_TZDATA=False)
  * icalvalue_new/set_date and icalvalue_new/set_datetime now
    enforce DATE and DATE-TIME values respectively.
  * draft-ietf-calext-extensions (RFC 7986) support added.
  * Parameter values are now en/decoded per RFC 6868.
  * Added support for VPATCH component.
- Disable building static libs, nothing seems to be using it.
- Remove 0001-build-ICU-must-appear-as-Requires-in-pkgconfig.patch,
  libical-boo986631-read-past-end.patch,
  libical-boo986631-check-prev-char.patch,
  libical-parser-sanity-check.patch,
  libical-timezone-use-after-free.patch,
  libical-boo1015964-use-after-free.patch (all are upstream)
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Jun 19 2017 mgorse@suse.com
- Add fixes for various crashes:
  libical-boo986631-read-past-end.patch
  libical-boo986631-check-prev-char.patch
  libical-parser-sanity-check.patch
  libical-timezone-use-after-free.patch
  libical-boo1015964-use-after-free.patch
  Fixes boo#986631 (CVE-2016-5827), boo#986639 (CVE-2016-5824),
  boo#1015964 (CVE-2016-9584), and boo#1044995.
* Mon Oct  3 2016 jengelh@inai.de
- Add 0001-build-ICU-must-appear-as-Requires-in-pkgconfig.patch
* Thu Sep 29 2016 jengelh@inai.de
- Fix wrong baselibs provides
* Fri Sep  9 2016 zaitor@opensuse.org
- Add pkgconfig(icu-i18n) BuildRequires: Build the new RSCALE
  support.
* Thu Jul 21 2016 dimstar@opensuse.org
- Update to version 2.0.0:
  + Lots of source code scrubbing.
  + RSCALE support (requires libicu).
  + CalDAV attachment support (draft-daboo-caldav-attachments).
  + Resurrect the Berkeley DB storage support.
  + Incorrect recurrence generation for weekly pattern
    (gh#libical/libical#83)
  + Handle RRULEs better.
  + Handle threading better.
- Drop reproducible-generator.patch: fixed upstream.
- Bump sonum to 2, following upstream (also update baselibs.conf).
* Thu Apr 14 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
- Drop libical-sle12-abi.patch:
  use standard libical 1.0.1 ABI for SP2.
* Tue Feb  3 2015 coolo@suse.com
- add reproducible-generator.patch from debian bug report to
  get reproducible builds (and predicatable API actually)
* Fri Dec 26 2014 badshah400@gmail.com
- Update to version 1.0.1:
  + Bug fixes:
  - issue74: Do not escape double quote character
  - issue80,issue92: fix crashes using
    icaltimezone_load_builtin_timezone() recursively
  - Fix icalcomponent_foreach_recurrence() and large durations
    between recurrences (e.g. FREQ=YEARLY)
  - Properly handle UTCOFFSETs of the form +/-00mmss
  - Properly skip bogus dates (e.g. 2/30, 4/31) in
    RRULE:FREQ=MONTHLY
  - Properly handle RRULE:FREQ=MONTHLY;BYDAY;BYMONTHDAY when
    DTSTART isn't on BYDAY
  - Fix RRULE:FREQ=YEARLY;BYDAY;BYWEEKNO - MUST use ISO weeks
  - Properly skip bogus dates (e.g. 2/29) in
    RRULE:FREQ=YEARLY[;BYMONTH][;BYMONTHDAY]
  + Build fixes/features:
  - Autotools build system is removed
  - CMake version 2.8.9 (or higher) is required (was CMake
    version 2.4.0)
  - Add new -DSHARED_ONLY and -DSTATIC_ONLY CMake options
  - Remove -DSTATIC_LIBRARY CMake option
  - MSYS2 builds (fixed instructions)
  - Now can build api documentation with make docs
  + Update tzdata to version 2014g
  + Support added for schedule params: agent, status, force-send
  + Added a UID to the VFREEBUSY component
  + Allow dates > 2038 if sizeof(time_t) > 4
  + Add properties from draft-ietf-tzdist-service
  + Add support for RRULE:FREQ=YEARLY;BYDAY;BYYEARDAY and fixed
    RRULE:FREQ=YEARLY;BYYEARDAY with negative days
  + More regression tests added, in particular for recurrence
  + Almost all compile warnings silenced
  + A bunch of Coverity Scan warnings silenced
  + Package cmake macros installed by package.
- Add libical-sle12-abi.patch:
  use enum values used in prior SLE12 package, for ABI
  compatibility (bsc#954161).
- Drop 941609-typo-fix_icaltime_days_in_year.patch:
  fixed upstream (bsc#941609).
* Mon Oct 20 2014 cxiong@suse.com
- Add 941609-typo-fix_icaltime_days_in_year.patch:
  Typo fix "icaltime_days_in_year". This bug doesn't affect any
  functionality of SLE-12, backport for code correctness and
  completeness (bsc#941609).
* Fri Sep 26 2014 coolo@suse.com
- disable parallel build, too unreliable
* Thu Sep 18 2014 jengelh@inai.de
- Use %%cmake macros so that %%optflags reliably lands on the build
  command lines
- Improve on RPM group classification
- Drop strange Recommends: from libical-doc to libical1
  (the latter does not offer any directly-usable feature when
  the docs are installed).
- Documentation subpackage should be noarch
* Sat Jun 15 2013 schwab@linux-m68k.org
- Build with %%{optflags}
* Sun Jun  9 2013 toddrme2178@gmail.com
- New 1.x package.
  This version uses the cmake build system
- Add devel-static subpackage
- Remove unneeded buildrequires
- Changed license from MPL-1.1 to MPL-1.0.  That is the license
  listed in the COPYING file and the headers.
- Removed scripts directory from documentation.  Putting perl
  files in the documentation directory is apparently no longer
  allowed.
- Ran spec-cleaner
* Sat Jan 28 2012 jengelh@medozas.de
- Changed: The -devel subpackage should require the lib package,
  not the main one
* Sat Jan 28 2012 tabraham@novell.com
- Update to version 0.48
  + Allow duration specifications containing week along with day
    and time. even though this is against the RFC, but apparently
    we generate such durations so we need to be able to read them
    back.  + handle the case of the ATTACH type be explicitly set
    to URI + added a lock to avoid threading problems when
    icaltimezone_parse_zone_tab is called on multiple threads
  + bugfixes
- removed patches deprecated by this release:
  - libical-0.46-fix-race.patch
  - libical-0.46-fix-fatal-error-macro-usage.patch
  - libical-0.46-fix-endless-loop.patch
* Mon Jan 23 2012 cdenicolo@suse.com
- license update: MPL-1.1 or LGPL-2.1
  is a dual license: MPL-1.1 or LGPL-2.1
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Sun Nov 20 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Fri Mar 11 2011 gber@opensuse.org
- update to version 0.46
  + allow control over how components, properties and parameters
    with unknown names are handled
  + renamed static set_zone_directory() to set_zonedir()
  + added appropriate icaltime_* functions as methods to
    icaltimetype
  + added icaltimetype.datetime for converting a icaltimetype to a
    python datetime
  + added icalarray_copy for easy copying of icalarrays
  + renamed icaltimetype.datetime to icaltimetype.as_datetime and
    added icaltimetype.from_datetime staticmethod
  + bugfixes
- correct licensing information
- run autoreconf since tarball misses autconf autgenerated files
  (sf#3072673)
- added libical-0.46-fix-race.patch from upstream svn which fixes a
  race in populating builtin timezone components
- added libical-0.46-fix-fatal-error-macro-usage.patch from
  upstream svn in order to replace broken ICAL_ERRORS_ARE_FATAL
  preprocessor conditions with the correct check for the macros
  value (sf#3140405)
- added libical-0.46-fix-fatal-error-macro-usage.patch from
  upstream svn which fixes endless loop in the recurrence
  calculation (sf#3177380)
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Wed Jan  6 2010 jengelh@medozas.de
- Package baselibs.conf
- Enable parallel build
* Sun Sep 27 2009 msuman@gnome.org
- Update to version 0.44:
  + Memory leak fixes by Alvaro Manera
  + Various build fixes
- Fixes for rpmlint warnings, remove the '--enable-python' configure
  option as python bindings were broken sometime ago.
* Mon Jan 12 2009 msuman@suse.de
- Update to version 0.43:
  + Incorporates bugfixes submitted by the GNOME Evolution team.
  + New API call icaltimezone_set_tzid_prefix() to allow downstream
    applications to generate tzid's with custom namespaces.
* Sat Dec 20 2008 msuman@suse.de
- Use proper RPM macros in the spec file, remove unnecessary
  options passed to the configure script.
* Mon Dec  1 2008 dmueller@suse.de
- update to 0.42:
  * Fix for storing inline attachments
  * Safety fix when formatting date strings
  * compile / portability fixes
* Thu Nov 27 2008 wstephenson@suse.de
- Backport from 0.42:
  * Fix for storing inline attachments
  * Safety fix when formatting date strings
* Wed Oct 15 2008 dmueller@suse.de
- update to 0.40:
  * adopt new memory management semantics from the Evolution fork of libical,
  essentially every function now has a _r variant as well.
  * CMake build system in parallel
  * Crash fixes
* Tue Sep 16 2008 dmueller@suse.de
- update to 0.33:
  - Massive merges from KDE PIM's fork of libical
* Tue Sep  2 2008 dmueller@suse.de
- update to 0.32:
  - Massive merges from Evolution Data Server
  and other sources.
* Wed May  7 2008 coolo@suse.de
- fix rename from libical
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Tue Jan 29 2008 sf@suse.de
- update to 0.27
  - Merges some patches from KDE and Citadel.
  - Updates timezone data to tzdata 2007c.
  - merges the libical forks from KDE, Evolution and SourceForge.
  - Updates timezone data to tzdata 2005j.
- rename library package to libical0
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Sep 26 2005 mls@suse.de
- make devel package require base package
* Wed Jan 19 2005 sf@suse.de
- fix use of uninitialized variable
* Mon Mar 22 2004 sf@suse.de
-  remove some temporary /object files in examples
* Wed Mar 17 2004 ro@suse.de
- re-apply patch to make it build
* Fri Feb  6 2004 adrian@suse.de
- update to version 0.24 RC4
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Thu Jul  3 2003 ro@suse.de
- added unpackaged files
* Fri Jan 17 2003 stark@suse.de
- update to cvs 20030116 for upcoming Mozilla 1.3
* Wed Dec 11 2002 stark@suse.de
- update to cvs 20021211 for Mozilla 1.3a
* Thu Oct 17 2002 stark@suse.de
- "update" to version 0.23a used and provided by mozilla.org
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Mon Jun 17 2002 meissner@suse.de
- rerun auto* tools
* Wed Apr 17 2002 rhafer@suse.de
- added missing header files to -devel subpackage
- moved *.so links to -devel subpackage
- uses %%{_libdir} now
* Tue Apr  2 2002 sf@suse.de
- initial version
